﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2016 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Core;
using HeuristicLab.Data;

namespace HeuristicLab.Algorithms.DataAnalysis {
  public interface IKernelFunction<in T> : ICovarianceFunction {
    /// <summary>
    /// Calculates a kernel measure between two aribitrary Vectors. The distance value d is 
    /// 1.) positive  d(x,y)>0
    /// 2.) symmetric d(x,y) = d(y,x)
    /// 3.) only dependent on the norm ||x-y|| (Radial Basis criterium)
    /// </summary>
    /// <param name="a">an array representing point x</param>
    /// <param name="b">>an array representing point y</param>
    /// <returns>d(x,y)</returns>
    double Get(T a, T b);


    IFixedValueParameter<DoubleValue> BetaParameter { get; }
  }
}
